filter_corecmotifs: Filter CoRecMotifs

View source: R/05_filter_corecmotifs.R

filter_corecmotifsR Documentation

Filter CoRecMotifs

Description

Filter a list of CoRecMotifs, retaining only those that satisfy all of your conditions.

Usage

filter_corecmotifs(
  corecmotifs,
  probe_set = NULL,
  pbm_condition = NULL,
  array_id = NULL,
  motif_strength = NULL,
  rolling_ic = NULL,
  seed_sequence = NULL,
  motif_name = NULL,
  match_name = NULL,
  match_altname = NULL,
  match_pvalue = NULL,
  match_cluster = NULL,
  output_file = NULL,
  check_corecmotifs = TRUE
)

Arguments

corecmotifs

list. The CoRecMotifs to filter.

probe_set

character or NULL. The probe sets to keep or NULL not to filter by probe set. (Default: NULL)

pbm_condition

character or NULL. The PBM conditions to keep or NULL not to filter by PBM condition. (Default: NULL)

array_id

character or NULL. The array IDs to keep or NULL not to filter by array ID. (Default: NULL)

motif_strength

numeric(1) or NULL. The minimum motif strength to keep or NULL not to filter by motif strength. (Default: NULL)

rolling_ic

numeric(1) or NULL. The minimum rolling IC to keep or NULL not to filter by rolling IC. (Default: NULL)

seed_sequence

character or NULL. The seed sequences to keep or NULL not to filter by seed sequence. (Default: NULL)

motif_name

character or NULL. The motif names to keep or NULL not to filter by motif name. (Default: NULL)

match_name

character or NULL. The match motif names to keep or NULL not to filter by match motif name. (Default: NULL)

match_altname

character or NULL. The match motif altnames to keep or NULL not to filter by match motif altname. (Default: NULL)

match_pvalue

numeric(1) or NULL. The maximum match p-value to keep or NULL not to filter by match p-value. (Default: NULL)

match_cluster

character or NULL. The match clusters to keep or NULL not to filter by match cluster. (Default: NULL)

output_file

character(1) or NULL. The path to the file where the results should be saved, or NULL not to save the results. (Default: NULL)

check_corecmotifs

logical(1). Should corecmotifs be checked for validity? Setting this to FALSE can increase speed, but if corecmotifs contains anything other than valid CoRecMotifs, it may produce uninformative error messages. (Default: TRUE)

Value

A list of CoRecMotifs that pass the given filters.

See Also

check_replicates() for filtering groups of replicate CoRecMotifs.

Examples

print("FILL THIS IN")

Siggers-Lab/hTF_array documentation built on Feb. 7, 2024, 11:25 p.m.