View source: R/04_zscore_table_to_corecmotifs.R
| zscore_table_to_corecmotifs | R Documentation |
Converts a table of fluorescence z-scores into a list of CoRecMotifs.
zscore_table_to_corecmotifs(
zscore_table,
zscore_columns,
array_id = NULL,
output_file = NULL
)
zscore_table |
|
zscore_columns |
|
array_id |
|
output_file |
|
This function creates a CoRecMotif for every possible
combination of the z-score columns listed in zscore_columns and the
non-background probe sets that appear in the probe_set column of
zscore_table. Each column listed in zscore_columns should contain data
from one PBM condition, and the column name will be used to populate the
pbm_condition slot of the resulting CoRecMotifs. The
names of the non-background probe sets found in the probe_set column will
populate the probe_set slot, and array_id (if provided) will populate the
array_id slot. If no array ID is provided, a random one will be generated
in the format "random_id_xxxxxxxx" where "xxxxxxxx" is replaced with a
randomly generated 8 digit number. The probe_set, pbm_condition, and
array_id slots will be pasted together to create a uniquely identifying
name for each CoRecMotif.
A list of CoRecMotifs, one for each possible
combination of the probe sets in zscore_table$probe_set and the PBM
conditions listed in zscore_columns.
hTF_v1_annotation for a description of the probe annotation columns.
print("FILL THIS IN")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.